@@ -17,7 +17,7 @@
 package twitter4j;
 
 import twitter4j.internal.http.HttpParameter;
-import twitter4j.internal.util.T4JInternalStringUtil;
+import twitter4j.internal.util.z_T4JInternalStringUtil;
 
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -32,7 +32,6 @@ public final class FilterQuery implements java.io.Serializable {
     private long[] follow;
     private String[] track;
     private double[][] locations;
-    private boolean includeEntities;
 
     /**
      * Creates a new FilterQuery
@@ -140,44 +139,29 @@ public final class FilterQuery implements java.io.Serializable {
         return this;
     }
 
-    /**
-     * Set whether to include extracted entities in the stream.
-     *
-     * @param include True if entities should be included, else false.
-     * @return this instance
-     * @since Twitter4J 2.1.4
-     */
-    public FilterQuery setIncludeEntities(boolean include) {
-        includeEntities = include;
-        return this;
-    }
-
-    /*package*/ HttpParameter[] asHttpParameterArray() {
+    /*package*/ HttpParameter[] asHttpParameterArray(HttpParameter stallWarningsParam) {
         ArrayList<HttpParameter> params = new ArrayList<HttpParameter>();
 
         params.add(new HttpParameter("count", count));
-        if (null != follow && follow.length > 0) {
+        if (follow != null && follow.length > 0) {
             params.add(new HttpParameter("follow"
-                    , T4JInternalStringUtil.join(follow)));
+                    , z_T4JInternalStringUtil.join(follow)));
         }
-        if (null != track && track.length > 0) {
+        if (track != null && track.length > 0) {
             params.add(new HttpParameter("track"
-                    , T4JInternalStringUtil.join(track)));
+                    , z_T4JInternalStringUtil.join(track)));
         }
-        if (null != locations && locations.length > 0) {
+        if (locations != null && locations.length > 0) {
             params.add(new HttpParameter("locations"
                     , toLocationsString(locations)));
         }
-        if (includeEntities) {
-            params.add(new HttpParameter("include_entities", true));
-        }
-
+        params.add(stallWarningsParam);
         HttpParameter[] paramArray = new HttpParameter[params.size()];
         return params.toArray(paramArray);
     }
 
     private String toLocationsString(final double[][] keywords) {
-        final StringBuffer buf = new StringBuffer(20 * keywords.length * 2);
+        final StringBuilder buf = new StringBuilder(20 * keywords.length * 2);
         for (double[] keyword : keywords) {
             if (0 != buf.length()) {
                 buf.append(",");
@@ -218,7 +202,6 @@ public final class FilterQuery implements java.io.Serializable {
                 ", follow=" + Arrays.toString(follow) +
                 ", track=" + (track == null ? null : Arrays.asList(track)) +
                 ", locations=" + (locations == null ? null : Arrays.asList(locations)) +
-                ", includeEntities=" + includeEntities +
                 '}';
     }
 }
