@@ -30,4 +30,16 @@ public interface ResponseList<T> extends TwitterResponse, List<T> {
      * {@inheritDoc}
      */
     public RateLimitStatus getRateLimitStatus();
+
+    /**
+     * Returns the current feature-specific rate limit status if available.<br>
+     * This method is available in conjunction with Twitter#searchUsers()<br>
+     *
+     * @return current rate limit status
+     * @see <a href="http://dev.twitter.com/pages/rate-limiting">Rate Limiting | dev.twitter.com</a>
+     * @see <a href="http://dev.twitter.com/pages/rate_limiting_faq">Rate Limiting FAQ | dev.twitter.com</a>
+     * @since Twitter4J 2.1.2
+     */
+    public RateLimitStatus getFeatureSpecificRateLimitStatus();
+
 }
