@@ -58,13 +58,13 @@ import java.util.Date;
 import java.util.EnumMap;
 import java.util.Map;
 import java.util.Map.Entry;
+import java.util.concurrent.ConcurrentLinkedQueue;
 import org.apache.commons.codec.binary.Base64;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Charsets;
-import com.openexchange.java.Java7ConcurrentLinkedQueue;
 import com.openexchange.java.Streams;
 import com.openexchange.mail.text.HtmlProcessing;
 import com.openexchange.mail.utils.DisplayMode;
@@ -229,7 +229,7 @@ public class MessagingMessageWriter {
         }
 
         @Override
-        public Object write(final MessagingPart part, final MessagingContent content, final ServerSession session, final DisplayMode mode) throws OXException {
+        public Object write(final MessagingPart part, final MessagingContent content, final ServerSession session, final DisplayMode mode) {
             if (null == session || null == mode) {
                 return ((StringContent) content).getData();
             }
@@ -344,12 +344,12 @@ public class MessagingMessageWriter {
     public MessagingMessageWriter() {
         super();
         // Header writers
-        headerWriters = new Java7ConcurrentLinkedQueue<MessagingHeaderWriter>();
+        headerWriters = new ConcurrentLinkedQueue<MessagingHeaderWriter>();
         headerWriters.add(new ContentTypeWriter());
         headerWriters.add(new ContentDispositionWriter());
         headerWriters.add(new AddressHeaderWriter());
         // Content writers
-        contentWriters = new Java7ConcurrentLinkedQueue<MessagingContentWriter>();
+        contentWriters = new ConcurrentLinkedQueue<MessagingContentWriter>();
         contentWriters.add(new StringContentRenderer());
         contentWriters.add(new BinaryContentRenderer());
         contentWriters.add(new ReferenceContentRenderer());
