@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,7 +55,7 @@ import java.util.concurrent.locks.Lock;
 import com.openexchange.exception.OXException;
 import com.openexchange.messaging.MessagingAccount;
 import com.openexchange.messaging.MessagingAccountManager;
-import com.openexchange.messaging.twitter.services.TwitterMessagingServiceRegistry;
+import com.openexchange.messaging.twitter.osgi.Services;
 import com.openexchange.messaging.twitter.session.TwitterAccessRegistry;
 import com.openexchange.oauth.OAuthAccount;
 import com.openexchange.oauth.OAuthConstants;
@@ -75,15 +75,10 @@ import com.openexchange.twitter.TwitterService;
 public abstract class AbstractTwitterMessagingAccess {
 
     protected final MessagingAccount account;
-
     protected final TwitterService twitterService;
-
     protected final TwitterAccess twitterAccess;
-
     protected final Session session;
-
     protected final String secret;
-
     protected boolean connected;
 
     /**
@@ -95,13 +90,8 @@ public abstract class AbstractTwitterMessagingAccess {
         super();
         this.session = session;
         this.account = account;
-        try {
-            twitterService = TwitterMessagingServiceRegistry.getServiceRegistry().getService(TwitterService.class, true);
-            secret = TwitterMessagingServiceRegistry.getServiceRegistry().getService(SecretService.class, true).getSecret(session);
-
-        } catch (final OXException e) {
-            throw e;
-        }
+        twitterService = Services.getService(TwitterService.class);
+        secret = Services.getService(SecretService.class).getSecret(session);
         final int contextId = session.getContextId();
         final int userId = session.getUserId();
         final int accountId = account.getId();
@@ -118,7 +108,7 @@ public abstract class AbstractTwitterMessagingAccess {
                  */
                 final OAuthAccount oAuthAccount;
                 {
-                    final OAuthService oAuthService = TwitterMessagingServiceRegistry.getServiceRegistry().getService(OAuthService.class, true);
+                    final OAuthService oAuthService = Services.getService(OAuthService.class);
                     /*
                      * Check presence of TwitterConstants.TWITTER_OAUTH_ACCOUNT
                      */
