@@ -74,14 +74,13 @@ import com.openexchange.exception.Category;
 import com.openexchange.exception.OXException;
 import com.openexchange.html.HtmlService;
 import com.openexchange.java.Strings;
-import com.openexchange.rss.FeedByDateSorter;
 import com.openexchange.rss.RssExceptionCodes;
 import com.openexchange.rss.RssResult;
 import com.openexchange.rss.osgi.Services;
 import com.openexchange.rss.preprocessors.RssPreprocessor;
 import com.openexchange.rss.preprocessors.SanitizingPreprocessor;
 import com.openexchange.rss.util.RssProperties;
-import com.openexchange.rss.util.TimeoutHttpURLFeedFetcher;
+import com.openexchange.rss.util.TimoutHttpURLFeedFetcher;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.session.ServerSession;
 import com.sun.syndication.feed.synd.SyndContent;
@@ -103,17 +102,33 @@ public class RssAction implements AJAXActionService {
     private static final int NOT_FOUND = 404;
     private static final int FORBIDDEN = 403;
 
+    private static final Comparator<RssResult> ASC = new Comparator<RssResult>() {
+
+        @Override
+        public int compare(RssResult r1, RssResult r2) {
+            return r1.getDate().compareTo(r2.getDate());
+        }
+    };
+
+    private static final Comparator<RssResult> DESC = new Comparator<RssResult>() {
+
+        @Override
+        public int compare(RssResult r1, RssResult r2) {
+            return r2.getDate().compareTo(r1.getDate());
+        }
+    };
+
     // ------------------------------------------------------------------------------------------------------------------------------
 
-    private final TimeoutHttpURLFeedFetcher fetcher;
-    private final HashMapFeedInfoCache     feedCache;
+    private final TimoutHttpURLFeedFetcher fetcher;
+    private final HashMapFeedInfoCache feedCache;
 
     /**
      * Initializes a new {@link RssAction}.
      */
     public RssAction() {
         feedCache = new HashMapFeedInfoCache();
-        fetcher = new TimeoutHttpURLFeedFetcher(10000, 30000, feedCache);
+        fetcher = new TimoutHttpURLFeedFetcher(10000, 30000, feedCache);
     }
 
     @Override
@@ -124,9 +139,7 @@ public class RssAction implements AJAXActionService {
         try {
             List<URL> urls = getUrls(request);
             feeds = getAcceptedFeeds(urls, warnings);
-        } catch (IllegalArgumentException e) {
-            throw AjaxExceptionCodes.IMVALID_PARAMETER.create(e, e.getMessage());
-        } catch (MalformedURLException e) {
+        } catch (IllegalArgumentException | MalformedURLException e) {
             throw AjaxExceptionCodes.IMVALID_PARAMETER.create(e, e.getMessage());
         } catch (IOException e) {
             throw AjaxExceptionCodes.IO_ERROR.create(e, e.getMessage());
@@ -141,63 +154,45 @@ public class RssAction implements AJAXActionService {
         List<RssResult> results = new ArrayList<RssResult>(feeds.size());
         boolean dropExternalImages = AJAXRequestDataTools.parseBoolParameter("drop_images", request, true);
         RssPreprocessor preprocessor = new SanitizingPreprocessor(dropExternalImages);
-        Date now = new Date();
 
+        // Iterate feeds
         for (SyndFeed feed : feeds) {
             if (feed == null) {
                 continue;
             }
 
             // Iterate feed's entries
-            String feedTitle = feed.getTitle();
-            String imageUrl = null;
-            String feedUrl;
-            try {
-                feedUrl = checkUrl(feed.getLink());
-                SyndImage image = feed.getImage();
-                if (image != null) {
-                    imageUrl = checkUrl(image.getUrl());
-                }
-            } catch (MalformedURLException e) {
-                throw RssExceptionCodes.INVALID_RSS.create(e, feed.getLink());
-            }
             for (Object obj : feed.getEntries()) {
                 SyndEntry entry = (SyndEntry) obj;
+
                 // Create appropriate RssResult instance
                 RssResult result;
                 try {
-                    result = new RssResult().setAuthor(entry.getAuthor()).setSubject(entry.getTitle()).setUrl(checkUrl(entry.getLink()));
-                    result.setFeedUrl(feedUrl).setFeedTitle(feedTitle).setDate(entry.getUpdatedDate(), entry.getPublishedDate(), now);
+                    result = new RssResult().setAuthor(entry.getAuthor()).setSubject(sanitiseString(entry.getTitle())).setUrl(checkUrl(entry.getLink()));
+                    result.setFeedUrl(checkUrl(feed.getLink())).setFeedTitle(sanitiseString(feed.getTitle())).setDate(entry.getUpdatedDate(), entry.getPublishedDate(), new Date());
                     // Check possible image
-                    if (imageUrl != null) {
-                        result.setImageUrl(imageUrl);
+                    SyndImage image = feed.getImage();
+                    if (image != null) {
+                        result.setImageUrl(checkUrl(image.getUrl()));
                     }
                 } catch (MalformedURLException e) {
                     throw RssExceptionCodes.INVALID_RSS.create(e, entry.getLink());
                 }
 
+                // Add to results list
                 results.add(result);
 
                 @SuppressWarnings("unchecked") List<SyndContent> contents = entry.getContents();
-                if (contents.isEmpty()) {
-                    /* Change for bug 52689: If no content is available at least display description */
-                    SyndContent description = entry.getDescription();
-                    if (null != description) {
-                        result.setBody(sanitiseString(description.getValue())).setFormat("text/html");
+                boolean foundHtml = false;
+                for (SyndContent content : contents) {
+                    if ("html".equals(content.getType())) {
+                        foundHtml = true;
+                        String htmlContent = preprocessor.process(content.getValue(), result);
+                        result.setBody(htmlContent).setFormat("text/html");
+                        break;
                     }
-                } else {
-                    boolean foundHtml = false;
-                    for (SyndContent content : contents) {
-                        String type = content.getType();
-                        if (null != type && (type.startsWith("htm") || type.startsWith("xhtm"))) {
-                            foundHtml = true;
-                            String htmlContent = preprocessor.process(content.getValue(), result);
-                            result.setBody(htmlContent).setFormat("text/html");
-                            break;
-                        }
-                        if (!foundHtml) {
-                            result.setBody(content.getValue()).setFormat(type);
-                        }
+                    if (!foundHtml) {
+                        result.setBody(content.getValue()).setFormat(content.getType());
                     }
                 }
             }
@@ -212,7 +207,7 @@ public class RssAction implements AJAXActionService {
             order = "DESC";
         }
         if (sort.equalsIgnoreCase("DATE")) {
-            Collections.sort(results, new FeedByDateSorter(order));
+            Collections.sort(results, "DESC".equalsIgnoreCase(order) ? DESC : ASC);
         }
 
         return new AJAXRequestResult(results, "rss").addWarnings(warnings);
@@ -220,7 +215,7 @@ public class RssAction implements AJAXActionService {
 
     /**
      * Retrieves all RSS URLs wrapped in the given request.
-     *
+     * 
      * @param request - the {@link AJAXRequestData} containing all feed URLs
      * @return {@link List} with desired feed URLs for further processing
      * @throws OXException
@@ -228,7 +223,7 @@ public class RssAction implements AJAXActionService {
      * @throws JSONException
      */
     protected List<URL> getUrls(AJAXRequestData request) throws OXException, MalformedURLException, JSONException {
-        List<URL> urls = new ArrayList<URL>();
+        List<URL> urls = new ArrayList<>();
 
         String urlString = "";
         JSONObject data = (JSONObject) request.requireData();
@@ -250,7 +245,7 @@ public class RssAction implements AJAXActionService {
 
     /**
      * Checks given URLs for validity (esp. host name blacklisting and port whitelisting) and adds not accepted feeds to the provided warnings list. Returns a list of accepted feeds for further processing
-     *
+     * 
      * @param urls - List of {@link URL}s to check
      * @param warnings - List of {@link OXException} that might be enhanced by possible errors
      * @return {@link List} of {@link SyndFeed}s that have been accepted for further processing
@@ -260,7 +255,7 @@ public class RssAction implements AJAXActionService {
         List<SyndFeed> feeds = new LinkedList<SyndFeed>();
 
         for (URL url : urls) {
-            if (RssProperties.isDenied(url.toString())) {
+            if (RssProperties.isDenied(url.getProtocol(), url.getHost(), url.getPort())) {
                 final OXException oxe = RssExceptionCodes.RSS_CONNECTION_ERROR.create(url.toString());
                 warnings.add(oxe);
                 continue;
@@ -336,19 +331,12 @@ public class RssAction implements AJAXActionService {
     }
 
     /**
-<<<<<<< HEAD
      * Sanitises the specified string via the {@link HtmlService}
-     *
+     * 
      * @param string The string to sanitise
      * @return The sanitised string if the {@link HtmlService} is available
-=======
-     * Sanitizes the specified string via the {@link HtmlService}
-     *
-     * @param string The string to sanitize
-     * @return The sanitized string as HTML content if the {@link HtmlService} is available
->>>>>>> 88a3504f07c... Fix for bug 56420: Return RSS Feed's subject as-is
      */
-    private static String sanitiseString(String string) throws OXException {
+    private static String sanitiseString(String string) {
         final HtmlService htmlService = Services.getService(HtmlService.class);
         if (htmlService == null) {
             LOG.warn("The HTMLService is unavailable at the moment, thus the RSS string '{}' might not be sanitised", string);
@@ -358,7 +346,7 @@ public class RssAction implements AJAXActionService {
     }
 
     private static String urlDecodeSafe(final String urlString) throws MalformedURLException {
-        if (isEmpty(urlString)) {
+        if (com.openexchange.java.Strings.isEmpty(urlString)) {
             return urlString;
         }
         try {
@@ -379,7 +367,7 @@ public class RssAction implements AJAXActionService {
      * @throws MalformedURLException If URL string is invalid
      */
     private static String checkUrl(final String sUrl) throws MalformedURLException {
-        if (isEmpty(sUrl)) {
+        if (com.openexchange.java.Strings.isEmpty(sUrl)) {
             // Nothing to check
             return sUrl;
         }
@@ -407,7 +395,7 @@ public class RssAction implements AJAXActionService {
     }
 
     private static String prepareUrlString(final String urlString) {
-        if (isEmpty(urlString)) {
+        if (com.openexchange.java.Strings.isEmpty(urlString)) {
             return urlString;
         }
         final String tmp = urlString.toLowerCase(Locale.US);
@@ -417,17 +405,4 @@ public class RssAction implements AJAXActionService {
         }
         return pos > 0 ? urlString.substring(pos) : urlString;
     }
-
-    /** Checks for an empty string */
-    private static boolean isEmpty(final String string) {
-        if (null == string) {
-            return true;
-        }
-        final int len = string.length();
-        boolean isWhitespace = true;
-        for (int i = 0; isWhitespace && i < len; i++) {
-            isWhitespace = com.openexchange.java.Strings.isWhitespace(string.charAt(i));
-        }
-        return isWhitespace;
-    }
 }
