@@ -90,7 +90,7 @@ public class RssActivator extends AJAXModuleActivator {
             public boolean isEnabled(String capability, Session ses) throws OXException {
                 if ("rss".equals(capability)) {
                     final ServerSession session = ServerSessionAdapter.valueOf(ses);
-                    if (session.isAnonymous()) {
+                    if (session.isAnonymous() || session.getUser().isGuest()) {
                         return false;
                     }
                     final ConfigViewFactory factory = getService(ConfigViewFactory.class);
